pub enum Unit {
PuppyManners,
LooseLeashWalking,
Recall,
ConfidenceBuilding,
CanineGoodCitizenPrep,
}Expand description
Curriculum unit that defines what trainers should work on and report against.
Variants
PuppyManners
Staff can see the puppy manners training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
LooseLeashWalking
Staff can see the loose leash walking training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
Recall
Staff can see the recall training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
ConfidenceBuilding
Staff can see the confidence building training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
CanineGoodCitizenPrep
Staff can see the canine good citizen prep training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.