pub enum Unit {
PuppyManners,
LooseLeashWalking,
Recall,
ConfidenceBuilding,
CanineGoodCitizenPrep,
}Expand description
Curriculum unit that defines what trainers should work on and report against.
Variants
PuppyManners
Puppy manners training operational signal for enrollment, curriculum, progress, package, or follow-up handling.
LooseLeashWalking
Loose leash walking training operational signal for enrollment, curriculum, progress, package, or follow-up handling.
Recall
Recall training operational signal for enrollment, curriculum, progress, package, or follow-up handling.
ConfidenceBuilding
Confidence building training operational signal for enrollment, curriculum, progress, package, or follow-up handling.
CanineGoodCitizenPrep
Canine good citizen prep training operational signal for enrollment, curriculum, progress, package, or follow-up handling.